@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 1999 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -30,9 +30,6 @@
 #include "dos2linux.h"
 #include "priv.h"
 #include "utilities.h"
-#ifdef X86_EMULATOR
-#include "cpu-emu.h"
-#endif
 #include "mhpdbg.h"
 
 
@@ -111,9 +108,6 @@ config_defaults(void)
     config.rdtsc = 0;
     config.mathco = 0;
     config.smp = 0;
-#ifdef X86_EMULATOR
-    config.emuspeed = 50;	/* instruction cycles per us */
-#endif
 
     open_proc_scan("/proc/cpuinfo");
     switch (get_proc_intvalue_by_key(
@@ -145,10 +139,6 @@ config_defaults(void)
 		fprintf (stderr,"kernel CPU speed is %Ld Hz\n",chz);
 /*		fprintf (stderr,"CPU speed factors %ld,%ld\n",
 			config.cpu_spd, config.cpu_tick_spd); */
-#ifdef X86_EMULATOR
-		config.emuspeed = di;
-		fprintf (stderr,"CPU-EMU speed is %d MHz\n",di);
-#endif
 		break;
 	    }
 	    else
@@ -186,9 +176,7 @@ config_defaults(void)
       config.realcpu, config.mathco);
 
     config.hdiskboot = 1;	/* default hard disk boot */
-#ifdef X86_EMULATOR
-    config.cpuemu = 0;
-#endif
+    config.mappingdriver = 0;
     config.mem_size = 640;
     config.ems_size = 0;
     config.ems_frame = 0xd000;
@@ -313,13 +301,8 @@ config_defaults(void)
     config.sb_base = 0x220;
     config.sb_dma = 1;
     config.sb_irq = 5;
-#ifdef __NetBSD__
-    config.sb_dsp = "/dev/sound";
-    config.sb_mixer = "/dev/mixer";
-#else
     config.sb_dsp = "/dev/dsp";
     config.sb_mixer = "/dev/mixer";
-#endif /* !__NetBSD__ */
     config.mpu401_base = 0x330;
 
     config.vnet = 1;
@@ -366,10 +349,8 @@ void dump_config_status(void *printfunc)
 
     (*print)("pci %d\nrdtsc %d\nmathco %d\nsmp %d\n",
                  config.pci, config.rdtsc, config.mathco, config.smp);
-#ifdef X86_EMULATOR
-    (*print)("emuspeed %d\ncpuemu %d\n", config.emuspeed, config.cpuemu);
-#endif
 
+    (*print)("mappingdriver %s\n", config.mappingdriver ? config.mappingdriver : "auto");
     (*print)("hdiskboot %d\nmem_size %d\n",
         config.hdiskboot, config.mem_size);
     (*print)("ems_size 0x%x\nems_frame 0x%x\nsecure %d\n",
@@ -780,13 +761,6 @@ config_init(int argc, char **argv)
 	usedoptions['L'] = 'L';
     }
 
-#if defined(__NetBSD__) && defined(X_SUPPORT) && defined(X_GRAPHICS)
-    { extern int selfmem_fd;
-    /* do this before any set*id functions are called */
-    selfmem_fd = open("/proc/curproc/mem", O_RDWR);
-    }
-#endif
-
     our_envs_init(usedoptions);
     parse_config(confname,dosrcname);
     restore_usedoptions(usedoptions);
@@ -799,10 +773,6 @@ config_init(int argc, char **argv)
     	fprintf(stderr, "CONF: emulated CPU forced down to real CPU: %ld86\n",vm86s.cpu_type);
     }
 
-#ifdef __NetBSD__
-    optreset = 1;
-    optind = 1;
-#endif
 #ifdef __linux__
     optind = 0;
 #endif
@@ -987,12 +957,6 @@ config_init(int argc, char **argv)
     c_printf(" uid=%d (cached %d) gid=%d (cached %d)\n",
         geteuid(), get_cur_euid(), getegid(), get_cur_egid());
 
-#ifdef X86_EMULATOR
-    if (config.cpuemu && config.speaker==SPKR_NATIVE) {
-	c_printf("SPEAKER: can`t use native mode with cpu-emu\n");
-	config.speaker=SPKR_EMULATED;
-    }
-#endif
     if (config_check_only) {
 	dump_config_status(0);
 	usage();
@@ -1053,9 +1017,9 @@ int parse_debugflags(const char *s, unsigned char flag)
     char            c;
     int ret = 0;
 #ifdef X_SUPPORT
-    const char      allopts[] = "dARWDCvXkiTsm#pgcwhIExMnPrSeZ";
+    const char      allopts[] = "dARWDCvXkiTsm#pQgcwhIExMnPrSeZ";
 #else
-    const char      allopts[] = "dARWDCvkiTsm#pgcwhIExMnPrSeZ";
+    const char      allopts[] = "dARWDCvkiTsm#pQgcwhIExMnPrSeZ";
 #endif
 
     /*
@@ -1155,6 +1119,9 @@ int parse_debugflags(const char *s, unsigned char flag)
 	case 'P':		/* Packet driver */
 	    d.pd = flag;
 	    break;
+	case 'Q':		/* Mapping driver */
+	    d.mapping = flag;
+	    break;
 	case 'r':		/* PIC */
 	    d.request = flag;
 	    break;
@@ -1167,11 +1134,6 @@ int parse_debugflags(const char *s, unsigned char flag)
 	case 'Z':
 	    d.pci = flag;       /* PCI */
 	    break;
-#ifdef X86_EMULATOR
-	case 'e':		/* cpu-emu */
-	    d.emu = flag;
-	    break;
-#endif
 	case 'a':{		/* turn all on/off depending on flag */
 		char           *newopts = (char *) malloc(strlen(allopts) + 2);
 
