@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 1999 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -40,11 +40,6 @@
  * DANG_END_REMARK
  */
 
-#ifdef __NetBSD__
-#define __ELF__				/* simulated with a.out mmap-ing stuff.
-					   use _main entrypoint. */
-#define EDEADLOCK EDEADLK
-#endif
 
 #ifndef __ELF__
 /*
@@ -78,16 +73,9 @@ __asm__("___START___: jmp _emulate\n");
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <limits.h>
-#ifndef __NetBSD__
 #include <getopt.h>
-#endif
 #include <assert.h>
 
-#ifdef __NetBSD__
-#include <signal.h>
-#include <machine/pcvt_ioctl.h>
-#include "netbsd_vm86.h"
-#endif
 #ifdef __linux__
 #if GLIBC_VERSION_CODE >= 2000
 #include <sys/vt.h>
@@ -140,14 +128,13 @@ __asm__("___START___: jmp _emulate\n");
 #ifdef USE_SBEMU
 #include "sound.h"
 #endif
-#ifdef X86_EMULATOR
-#include "cpu-emu.h"
-#endif
 
 extern void     stdio_init(void);
 extern void     time_setting_init(void);
 extern void     low_mem_init(void);
-
+extern void	mapping_init(void);
+extern void	mapping_close(void);
+extern void	pcibios_init(void);
 extern void     shared_memory_exit(void);
 extern void     restore_vt(u_short);
 extern void     disallocate_vt(void);
@@ -159,9 +146,6 @@ extern void     print_version(void);
 
 extern void io_select_init(void);
 
-#ifdef USE_THREADS
-extern void treads_init(void);
-#endif
 
 jmp_buf NotJEnv;
 
@@ -250,7 +234,7 @@ static SillyG_t SillyG_[16 + 1];
 static inline void 
 SIG_init()
 {
-#if defined(SIG) && defined(REQUIRES_VM86PLUS)
+#if defined(SIG)
     PRIV_SAVE_AREA
     /* Get in touch with Silly Interrupt Handling */
     if (config.sillyint) {
@@ -289,7 +273,7 @@ SIG_init()
 static inline void 
 SIG_close()
 {
-#if defined(SIG) && defined(REQUIRES_VM86PLUS)
+#if defined(SIG)
     if (SillyG) {
 	SillyG_t       *sg = SillyG;
 	while (sg->fd) {
@@ -304,7 +288,6 @@ SIG_close()
 static inline void 
 vm86plus_init(void)
 {
-#ifdef REQUIRES_VM86PLUS
     static inline int vm86_old(struct vm86_struct* v86)
     {
         int __res;
@@ -321,7 +304,6 @@ vm86plus_init(void)
     fflush(stdout);
     fflush(stderr);
     _exit(1);
-#endif
 }
 
 static inline void
@@ -332,37 +314,48 @@ module_init(void)
     memcheck_init();		/* lower 1M memory map support */
 }
 
-#ifdef __NetBSD__
-#include <machine/segments.h>
-/*
- * Switch all segment registers to use well-known GDT entries.
- * (The default process setup uses LDT entries for all segment registers)
- */
-static u_short csel = GSEL(GUCODE_SEL, SEL_UPL);
-asm(".text");
-asm(".align 4");
-asm(".globl changesegs_lret");
-asm("changesegs_lret:");
-asm("popl %eax");
-asm("pushl _csel");
-asm("pushl %eax");
-asm("lret");
 
-void
-changesegs()
+static void do_liability_disclaimer_prompt(void)
 {
-    register u_short dsel = GSEL(GUDATA_SEL, SEL_UPL);
-    u_long retaddr;
+  FILE *f;
+  char buf[32];
+  char disclaimer_file_name[256];
+  static char text[] ="
+  The Linux DOSEMU, Copyright (C) 2000 the 'DOSEMU-Development-Team'.
+  This program is  distributed  in  the  hope that it will be useful,
+  but  WITHOUT  ANY  WARRANTY;   without even the implied warranty of
+  MERCHANTABILITY  or  FITNESS FOR A PARTICULAR PURPOSE. See the file
+  COPYING for more details.  Use  this  programm  at  your  own risk!
 
-    asm("pushl %0; popl %%ds" : : "g" (dsel) );
-    asm("pushl %0; popl %%es" : : "g" (dsel) );
-    asm("movl %0,%%fs" : : "r" (dsel) );
-    asm("movl %0,%%gs" : : "r" (dsel) );
-    asm("movl %0,%%ss" : : "r" (dsel) );
-    asm("call changesegs_lret");
-    return;
+  By continuing execution of this programm,  you are stating that you
+  have read the file  COPYING  and the above liability disclaimer and
+  that you accept these conditions.
+
+  Enter 'yes' to confirm/continue: ";
+
+
+  snprintf(disclaimer_file_name, 256, "%s/disclaimer", LOCALDIR);
+  if (exists_file(disclaimer_file_name)) return;
+
+  fputs(text, stdout);
+  fgets(buf, sizeof(buf), stdin);
+  if (strncmp(buf, "yes", 3)) {
+    exit(1);
+  }
+
+  /*
+   * We now remember this by writing the above text to a
+   * in LOCALDIR/disclaimer
+   */
+   f = fopen(disclaimer_file_name, "w");
+   if (!f) {
+     fprintf(stderr, "cannot create %s\n", disclaimer_file_name);
+     exit(1);
+   }
+   fprintf(f, "%s%s\n", text, buf);
+   fclose(f);
 }
-#endif
+
 
 /*
  * DANG_BEGIN_FUNCTION emulate
@@ -391,9 +384,6 @@ emulate(int argc, char **argv)
 {
     extern void parse_dosemu_users(void);
     int e;
-#ifdef __NetBSD__
-    changesegs();
-#endif
 
     srand(time(NULL));
     memset(&config, 0, sizeof(config));
@@ -407,14 +397,6 @@ emulate(int argc, char **argv)
 	_exit(1);		/* just in case */
     }
 
-#ifdef USE_THREADS
-    treads_init();		/* init the threads system,
-				 * after this we will be thread0.
-				 * Because treads_init() captures SIGTERM
-				 * and signal_init() also does it,
-				 * we capture it via 'exit'.
-    				 */
-#endif
     /* NOW! it is safe to touch the priv code.  */
     priv_init();  /* This must come first! */
 
@@ -426,6 +408,12 @@ emulate(int argc, char **argv)
      */
     parse_dosemu_users();
 
+    /*
+     * Do the 'liability disclaimer' stuff we need to avoid problems
+     * with laws in some countries.
+     */
+    do_liability_disclaimer_prompt();
+
     /* the transposal of (config_|stdio_)init allows the addition of -o */
     /* to specify a debug out filename, if you're wondering */
 
@@ -440,6 +428,7 @@ emulate(int argc, char **argv)
 #endif
     get_time_init();
     stdio_init();		/* initialize stdio & open debug file */
+    mapping_init();		/* initialize mapping drivers */
     print_version();            /* log version information */
     module_init();
     low_mem_init();		/* initialize the lower 1Meg */
@@ -570,9 +559,6 @@ leavedos(int sig)
     struct itimerval itv;
     extern int errno;
     extern void do_r3da_pending (void);	/* emuretrace stuff */
-#if defined(X86_EMULATOR) && defined(EMU_STAT)
-    extern void print_emu_stat(void);
-#endif
    
     if (leavedos_recurse_check)
       {
@@ -635,12 +621,7 @@ leavedos(int sig)
     keyb_server_close();
     keyb_client_close();
 
-#if defined(X86_EMULATOR) && defined(EMU_STAT)
-    /* if we are here with config.cpuemu>1 something went wrong... */
-    if (config.cpuemu>1) { d.emu=1; print_emu_stat(); d.emu=config.cpuemu=0; }
-#else
     show_ints(0, 0x33);
-#endif
     g_printf("calling disk_close_all\n");
     disk_close_all();
     g_printf("calling video_close\n");
@@ -668,6 +649,10 @@ leavedos(int sig)
     g_printf("closing debugger pipes\n");
     mhp_close();
 #endif
+
+    g_printf("calling mapping_close()\n");
+    mapping_close();
+
     if (config.detach) {
 	restore_vt(config.detach);
 	disallocate_vt();
@@ -699,14 +684,7 @@ leavedos(int sig)
        }
     }
 
-#ifdef USE_THREADS
-    {
-	extern void Exit(int status);
-	Exit(sig);
-    }
-#else
     _exit(sig);
-#endif
 }
 
 #if 0
@@ -748,21 +726,3 @@ activate(int con_num)
     } else
 	do_ioctl(kbd_fd, VT_ACTIVATE, con_num);
 }
-
-#ifdef __NetBSD__
-void
-usleep(u_int microsecs)
-{
-    /* system usleep is ghastly inefficient, using SIGALRM.
-       Instead, we use select :) */
-    struct timeval tv;
-    tv.tv_sec = microsecs / 1000000;
-    tv.tv_usec = microsecs % 1000000;
-    select(0, 0, 0, 0, &tv);
-    /* return early if awoken */
-    return;
-}
-
-
-
-#endif
