@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 1999 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -47,13 +47,9 @@ typedef struct { int fd; int irq; } SillyG_t;
  * DANG_END_REMARK
 */ 
 
-#ifdef REQUIRES_VM86PLUS
-  EXTERN struct vm86plus_struct vm86s INIT ( {
+EXTERN struct vm86plus_struct vm86s INIT ( {
    {0},0,0,0,{{0}},{{0}}, {0}
-  } );
-#else
-  EXTERN struct vm86_struct vm86s;
-#endif
+} );
 
 EXTERN fd_set fds_sigio, fds_no_sigio;
 EXTERN unsigned int use_sigio INIT(0);
@@ -98,7 +94,7 @@ EXTERN char *cl,		/* clear screen */
 /* the fd for the keyboard */ 
 EXTERN int console_fd INIT(-1);
 
-/* the file descriptor for /dev/mem when mmap'ing the video mem */
+/* the file descriptor for /dev/mem mmap'ing */
 EXTERN int mem_fd INIT(-1);
 EXTERN int in_readkeyboard;
 
@@ -107,10 +103,6 @@ EXTERN int keypipe;
 EXTERN int mousepipe;
 
 EXTERN int in_vm86 INIT(0);
-#ifdef X86_EMULATOR
-EXTERN int in_vm86_emu INIT(0);
-EXTERN int in_dpmi_emu INIT(0);
-#endif
 
 EXTERN int li, co;	/* lines, columns */
 EXTERN int scanseq;
@@ -149,11 +141,7 @@ void getKeys(void);
 
      int set_ioperm(int, int, int);
 
-#ifdef X86_EMULATOR
 EXTERN struct debug_flags d INIT({0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0});
-#else
-EXTERN struct debug_flags d INIT({0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0});
-#endif
 #ifdef DONT_DEBUG_BOOT
 EXTERN struct debug_flags d_save;
 #endif
@@ -240,10 +228,6 @@ typedef struct vesamode_type_struct {
      typedef struct config_info {
        int hdiskboot;
 
-#ifdef X86_EMULATOR
-       boolean cpuemu;
-       int emuspeed;
-#endif
        /* for video */
        boolean console;
        boolean console_video;
@@ -356,6 +340,9 @@ typedef struct vesamode_type_struct {
        char *tty_lockfile;	/* Lock file pretext ie LCK.. */
        boolean tty_lockbinary;	/* Binary lock files ? */
 
+       /* type of mapping driver */
+       char *mappingdriver;
+
        /* list of arbitrary features
         * (at minimum 1, will be increased when needed)
         * The purpose of these parameters is to switch between code
@@ -454,10 +441,6 @@ EXTERN void sigalrm(int, struct sigcontext_struct);
 EXTERN void sigio(int, struct sigcontext_struct);
 EXTERN int dosemu_sigaction(int sig, struct sigaction *new, struct sigaction *old);
 #endif
-#ifdef __NetBSD__
-EXTERN void sigalrm(int, int, struct sigcontext *);
-EXTERN void sigio(int, int, struct sigcontext *);
-#endif
 
 /* signals for Linux's process control of consoles */
 #define SIG_RELEASE     SIGWINCH
@@ -499,29 +482,6 @@ do { \
        sigaddset(x, SIG_ACQUIRE); \
 } while(0)
 
-#ifdef __NetBSD__
-#define SignalHandler sig_t
-#define __sighandler_t sig_t
-
-#define NEWSETQSIG(sig, fun)	sa.sa_handler = (__sighandler_t)fun; \
-					sa.sa_flags = SA_RESTART|SA_ONSTACK ; \
-					sigemptyset(&sa.sa_mask); \
-					ADDSET_SIGNALS_THAT_QUEUE(&sa.sa_mask); \
-					sigaction(sig, &sa, NULL);
-
-#define SETSIG(sig, fun)	sa.sa_handler = (__sighandler_t)fun; \
-					sa.sa_flags = SA_RESTART; \
-					sigemptyset(&sa.sa_mask); \
-					sigaddset(&sa.sa_mask, SIG_TIME); \
-					sigaction(sig, &sa, NULL);
-
-#define NEWSETSIG(sig, fun) \
-			sa.sa_handler = (__sighandler_t) fun; \
-			sa.sa_flags = SA_RESTART|SA_ONSTACK; \
-			sigemptyset(&sa.sa_mask); \
-			sigaddset(&sa.sa_mask, SIG_TIME); \
-			sigaction(sig, &sa, NULL);
-#endif
 #ifdef __linux__
 #if GLIBC_VERSION_CODE
 #define SignalHandler __sighandler_t
@@ -587,10 +547,6 @@ EXTERN int fatalerr INIT(0);
 EXTERN int running_DosC INIT(0);
 EXTERN int dosc_interface(void);
 
-#ifdef __NetBSD__
-#define iopl(value)			{ EXTERN int errno; if (i386_iopl(value) == -1) { g_printf("iopl failed: %s\n", strerror(errno)); leavedos(4);}}
-#endif
-
 EXTERN void signal_init(void);
 EXTERN void device_init(void);
 EXTERN void hardware_setup(void);
