@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 1999 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -126,12 +126,6 @@
  */
 #define INT10_WATCHER_SEG	ROMBIOSSEG
 #define INT10_WATCHER_OFF	0x4240
-#ifdef X86_EMULATOR
-#define CPUEMU_WATCHER_SEG	ROMBIOSSEG
-#define CPUEMU_WATCHER_OFF	0x42A0
-#define CPUEMUI10_ADD		((CPUEMU_WATCHER_SEG << 4) +\
-				  CPUEMU_WATCHER_OFF + 11)
-#endif
 
 /* This inline interrupt is used for FCB open calls */
 #define INTE7_SEG	ROMBIOSSEG
