@@ -1,6 +1,6 @@
 /* 
  * All modifications in this file to the original code are
- * (C) Copyright 1992, ..., 1999 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -451,10 +451,6 @@ unsigned char VGA_emulate_inb(ioport_t);
 int vga_emu_fault(struct sigcontext_struct *);
 #define VGA_EMU_FAULT(scp,code) vga_emu_fault(scp)
 #endif
-#ifdef __NetBSD__
-int vga_emu_fault(struct sigcontext *, int);
-#define VGA_EMU_FAULT vga_emu_fault
-#endif
 int vga_emu_init(vgaemu_display_type *);
 void vga_emu_done(void);
 int vga_emu_update(vga_emu_update_type *);
